#!/usr/bin/env python3
"""
ARP Network Scanner
Parameters:
    - IP: Network IP (e.g., 192.168.1.0/24)
Requires: scapy package
"""
from scapy.all import ARP, Ether, srp
import argparse
import sys
import time

def scan_network(network):
    try:
        # Create ARP request packet
        arp = ARP(pdst=network)
        ether = Ether(dst="ff:ff:ff:ff:ff:ff")
        packet = ether/arp

        print(f"Scanning network {network}...")
        start_time = time.time()

        # Send packet and get response
        result = srp(packet, timeout=3, verbose=0)[0]

        # Process results
        devices = []
        for sent, received in result:
            devices.append({'ip': received.psrc, 'mac': received.hwsrc})

        # Print results
        print(f"\nFound {len(devices)} devices:")
        print("IP Address\t\tMAC Address")
        print("-" * 40)
        for device in devices:
            print(f"{device['ip']}\t\t{device['mac']}")

        print(f"\nScan completed in {time.time() - start_time:.2f} seconds")

    except Exception as e:
        print(f"Error during scan: {str(e)}")
        sys.exit(1)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="ARP Network Scanner")
    parser.add_argument("network", help="Network to scan (e.g., 192.168.1.0/24)")
    args = parser.parse_args()
    
    scan_network(args.network)
